var VueAdvanceDialog = (function (exports, emitter) {
    'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var emitter__default = /*#__PURE__*/_interopDefaultLegacy(emitter);

    var EventHub = {
        $on: function () {
            var args = [], len = arguments.length;
            while ( len-- ) args[ len ] = arguments[ len ];

            return emitter__default["default"].on.apply(emitter__default["default"], args);
    },
        $once: function () {
            var args = [], len = arguments.length;
            while ( len-- ) args[ len ] = arguments[ len ];

            return emitter__default["default"].once.apply(emitter__default["default"], args);
    },
        $off: function () {
            var args = [], len = arguments.length;
            while ( len-- ) args[ len ] = arguments[ len ];

            return emitter__default["default"].off.apply(emitter__default["default"], args);
    },
        $emit: function () {
            var args = [], len = arguments.length;
            while ( len-- ) args[ len ] = arguments[ len ];

            return emitter__default["default"].emit.apply(emitter__default["default"], args);
    },
    };

    //

    var script = {
        name: 'vue-advance-dialog',

        props: {
            id: {
                type: String,
                required: true,
                default: 'g-dialog_' + Number(Math.random() * 100).toFixed(0)
            },
            toggleClass: {
                type: String,
                required: false,
                default: 'btn btn-primary'
            },
            toggleTitle: {
                type: String,
                required: false,
                default: ''
            },
            hideHeader: {
                type: Boolean,
                required: false,
                default: false
            },
            hideBody: {
                type: Boolean,
                required: false,
                default: false
            },
            disabled: {
                type: Boolean,
                required: false,
                default: false
            },
            hideFooter: {
                type: Boolean,
                required: false,
                default: true
            },
            hideCloseButton: {
                type: Boolean,
                required: false,
                default: false
            },
            hideToggle: {
                type: Boolean,
                required: false,
                default: true
            },
            size: {
                type: String,
                required: false,
                default: 'xs'
                // lg, md, sm, xs
            },
            position: {
                type: String,
                required: false,
                default: 'top-center'
                // center-center, center-left, center-right, top-center, top-left, top-right, bottom-center, bottom-left, bottom-right
            },
            title: {
                type: String,
                required: false,
                default: ''
            },
            containerClass: {
                type: String,
                required: false,
                default: ''
            },
            contentClass: {
                type: String,
                required: false,
                default: ''
            },
            contentHeaderClass: {
                type: String,
                required: false,
                default: ''
            },
            contentInnerClass: {
                type: String,
                required: false,
                default: ''
            },
            contentFooterClass: {
                type: String,
                required: false,
                default: ''
            },
            transition: {
                type: String,
                required: false,
                default: 'slide-top'
            },
        },

        data: function data() {
            return {
                isActive: false,
                activated: false,
            };
        },
        watch: {
            isActive: function isActive(value) {
                if (value === true) {
                    this.$emit('activated');
                } else {
                    this.$emit('deactivated');
                }
            }
        },
        mounted: function mounted() {
            var this$1$1 = this;

            EventHub.$on('hide-all-dialog', function () {
                this$1$1.hideDialog();
            });
            EventHub.$on('hide-dialog', function (id) {
                if (this$1$1.id !== id) { return }
                this$1$1.hideDialog();
            });

            EventHub.$on('show-dialog', function (id) {
                if (this$1$1.id !== id) { return }
                this$1$1.showDialog();
            });
        },
        methods: {
            showDialog: function showDialog() {
                var this$1$1 = this;

                this.isActive = true;
                this.$emit('after-show');
                setTimeout(function () {
                    this$1$1.activated = true;
                }, 100);
            },

            hideDialog: function hideDialog() {
                var this$1$1 = this;

                this.activated = false;
                this.$emit('after-hide');
                return setTimeout(function () {
                    this$1$1.isActive = false;
                }, 200)
            }
        }
    };

    function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
        if (typeof shadowMode !== 'boolean') {
            createInjectorSSR = createInjector;
            createInjector = shadowMode;
            shadowMode = false;
        }
        // Vue.extend constructor export interop.
        var options = typeof script === 'function' ? script.options : script;
        // render functions
        if (template && template.render) {
            options.render = template.render;
            options.staticRenderFns = template.staticRenderFns;
            options._compiled = true;
            // functional template
            if (isFunctionalTemplate) {
                options.functional = true;
            }
        }
        // scopedId
        if (scopeId) {
            options._scopeId = scopeId;
        }
        var hook;
        if (moduleIdentifier) {
            // server build
            hook = function (context) {
                // 2.3 injection
                context =
                    context || // cached call
                        (this.$vnode && this.$vnode.ssrContext) || // stateful
                        (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
                // 2.2 with runInNewContext: true
                if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                    context = __VUE_SSR_CONTEXT__;
                }
                // inject component styles
                if (style) {
                    style.call(this, createInjectorSSR(context));
                }
                // register component module identifier for async chunk inference
                if (context && context._registeredComponents) {
                    context._registeredComponents.add(moduleIdentifier);
                }
            };
            // used by ssr in case component is cached and beforeCreate
            // never gets called
            options._ssrRegister = hook;
        }
        else if (style) {
            hook = shadowMode
                ? function (context) {
                    style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
                }
                : function (context) {
                    style.call(this, createInjector(context));
                };
        }
        if (hook) {
            if (options.functional) {
                // register for functional component in vue file
                var originalRender = options.render;
                options.render = function renderWithStyleInjection(h, context) {
                    hook.call(context);
                    return originalRender(h, context);
                };
            }
            else {
                // inject component registration as beforeCreate hook
                var existing = options.beforeCreate;
                options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
            }
        }
        return script;
    }

    var isOldIE = typeof navigator !== 'undefined' &&
        /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
    function createInjector(context) {
        return function (id, style) { return addStyle(id, style); };
    }
    var HEAD;
    var styles = {};
    function addStyle(id, css) {
        var group = isOldIE ? css.media || 'default' : id;
        var style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
        if (!style.ids.has(id)) {
            style.ids.add(id);
            var code = css.source;
            if (css.map) {
                // https://developer.chrome.com/devtools/docs/javascript-debugging
                // this makes source maps inside style tags work properly in Chrome
                code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
                // http://stackoverflow.com/a/26603875
                code +=
                    '\n/*# sourceMappingURL=data:application/json;base64,' +
                        btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
                        ' */';
            }
            if (!style.element) {
                style.element = document.createElement('style');
                style.element.type = 'text/css';
                if (css.media)
                    { style.element.setAttribute('media', css.media); }
                if (HEAD === undefined) {
                    HEAD = document.head || document.getElementsByTagName('head')[0];
                }
                HEAD.appendChild(style.element);
            }
            if ('styleSheet' in style.element) {
                style.styles.push(code);
                style.element.styleSheet.cssText = style.styles
                    .filter(Boolean)
                    .join('\n');
            }
            else {
                var index = style.ids.size - 1;
                var textNode = document.createTextNode(code);
                var nodes = style.element.childNodes;
                if (nodes[index])
                    { style.element.removeChild(nodes[index]); }
                if (nodes.length)
                    { style.element.insertBefore(textNode, nodes[index]); }
                else
                    { style.element.appendChild(textNode); }
            }
        }
    }

    /* script */
    var __vue_script__ = script;

    /* template */
    var __vue_render__ = function() {
      var _vm = this;
      var _h = _vm.$createElement;
      var _c = _vm._self._c || _h;
      return _c(
        "div",
        {
          staticClass: "g-dialog",
          class: _vm.containerClass,
          attrs: { id: _vm.id }
        },
        [
          !_vm.hideToggle
            ? _c(
                "button",
                {
                  staticClass: "g-dialog__toggle",
                  class: _vm.toggleClass,
                  attrs: { type: "button", disabled: _vm.disabled },
                  on: { click: _vm.showDialog }
                },
                [
                  _vm._v(
                    "\n        " +
                      _vm._s(_vm.toggleTitle ? _vm.toggleTitle : "") +
                      "\n        "
                  ),
                  _vm._t("toggle")
                ],
                2
              )
            : _vm._e(),
          _vm._v(" "),
          _c("transition", { attrs: { name: "dialog-fade" } }, [
            _vm.isActive
              ? _c(
                  "div",
                  { staticClass: "g-dialog__inner", class: _vm.position },
                  [
                    _c("div", {
                      staticClass: "g-dialog__overlay",
                      on: { click: _vm.hideDialog }
                    }),
                    _vm._v(" "),
                    _c(
                      "transition",
                      { attrs: { name: "dialog-" + _vm.transition } },
                      [
                        _vm.activated
                          ? _c(
                              "div",
                              {
                                staticClass: "g-dialog__content",
                                class:
                                  "g-dialog__content--" +
                                  _vm.size +
                                  "" +
                                  _vm.contentClass
                              },
                              [
                                !_vm.hideCloseButton
                                  ? _c("button", {
                                      staticClass: "g-dialog__close-btn",
                                      attrs: { type: "button" },
                                      on: { click: _vm.hideDialog }
                                    })
                                  : _vm._e(),
                                _vm._v(" "),
                                !_vm.hideHeader
                                  ? _c(
                                      "div",
                                      {
                                        staticClass: "g-dialog__content-header",
                                        class: _vm.contentHeaderClass
                                      },
                                      [
                                        _vm._t("header"),
                                        _vm._v(" "),
                                        _vm.title
                                          ? _c("h5", {
                                              staticClass:
                                                "g-dialog__content-title",
                                              domProps: {
                                                textContent: _vm._s(_vm.title)
                                              }
                                            })
                                          : _vm._e()
                                      ],
                                      2
                                    )
                                  : _vm._e(),
                                _vm._v(" "),
                                !_vm.hideBody
                                  ? _c(
                                      "div",
                                      {
                                        staticClass: "g-dialog__content-inner",
                                        class: _vm.contentInnerClass
                                      },
                                      [_vm._t("default")],
                                      2
                                    )
                                  : _vm._t("default"),
                                _vm._v(" "),
                                !_vm.hideFooter
                                  ? _c(
                                      "div",
                                      {
                                        staticClass: "g-dialog__content-footer",
                                        class: _vm.contentFooterClass
                                      },
                                      [_vm._t("footer")],
                                      2
                                    )
                                  : _vm._e()
                              ],
                              2
                            )
                          : _vm._e()
                      ]
                    )
                  ],
                  1
                )
              : _vm._e()
          ])
        ],
        1
      )
    };
    var __vue_staticRenderFns__ = [];
    __vue_render__._withStripped = true;

      /* style */
      var __vue_inject_styles__ = function (inject) {
        if (!inject) { return }
        inject("data-v-4f566832_0", { source: ".g-dialog {\n  width: auto;\n  height: auto;\n}\n.g-dialog__inner {\n  position: fixed;\n  top: 0;\n  bottom: 0;\n  left: 0;\n  right: 0;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  z-index: 9999;\n  padding: 30px;\n  overflow: hidden;\n  overflow-Y: auto;\n}\n@media (max-width: 1200px) {\n.g-dialog__inner {\n    padding: 28px;\n}\n}\n@media (max-width: 992px) {\n.g-dialog__inner {\n    padding: 26px;\n}\n}\n@media (max-width: 768px) {\n.g-dialog__inner {\n    padding: 24px;\n}\n}\n@media (max-width: 576px) {\n.g-dialog__inner {\n    padding: 20px;\n}\n}\n.g-dialog__inner.center-center {\n  align-items: center;\n  justify-content: center;\n}\n.g-dialog__inner.center-left {\n  align-items: center;\n  justify-content: flex-start;\n}\n.g-dialog__inner.center-right {\n  align-items: center;\n  justify-content: flex-end;\n}\n.g-dialog__inner.top-center {\n  align-items: flex-start;\n  justify-content: center;\n}\n.g-dialog__inner.top-left {\n  align-items: flex-start;\n  justify-content: flex-start;\n}\n.g-dialog__inner.top-right {\n  align-items: flex-start;\n  justify-content: flex-end;\n}\n.g-dialog__inner.bottom-center {\n  align-items: flex-end;\n  justify-content: center;\n}\n.g-dialog__inner.bottom-left {\n  align-items: flex-end;\n  justify-content: flex-start;\n}\n.g-dialog__inner.bottom-right {\n  align-items: flex-end;\n  justify-content: flex-end;\n}\n.g-dialog__overlay {\n  position: fixed;\n  top: 0;\n  bottom: 0;\n  left: 0;\n  right: 0;\n  cursor: pointer;\n  z-index: 1;\n  background-color: rgba(2, 11, 44, 0.6);\n}\n.g-dialog__content {\n  height: auto;\n  background-color: #fff;\n  z-index: 4;\n  border-radius: 5px;\n  position: relative;\n  overflow: hidden;\n  padding: 45px;\n  box-shadow: 15px 10px 30px 0 rgba(0, 0, 0, 0.05);\n}\n@media (max-width: 1200px) {\n.g-dialog__content {\n    padding: 40px;\n}\n}\n@media (max-width: 992px) {\n.g-dialog__content {\n    padding: 35px;\n}\n}\n@media (max-width: 768px) {\n.g-dialog__content {\n    padding: 30px;\n}\n}\n@media (max-width: 576px) {\n.g-dialog__content {\n    padding: 25px;\n}\n}\n.g-dialog__content--lg {\n  width: 1100px;\n}\n@media (max-width: 1200px) {\n.g-dialog__content--lg {\n    width: 900px;\n}\n}\n@media (max-width: 992px) {\n.g-dialog__content--lg {\n    width: 700px;\n}\n}\n@media (max-width: 768px) {\n.g-dialog__content--lg {\n    width: 100%;\n}\n}\n.g-dialog__content--md {\n  width: 900px;\n}\n@media (max-width: 992px) {\n.g-dialog__content--md {\n    width: 700px;\n}\n}\n@media (max-width: 768px) {\n.g-dialog__content--md {\n    width: 100%;\n}\n}\n@media (max-width: 576px) {\n.g-dialog__content--md {\n    width: 100%;\n}\n}\n.g-dialog__content--sm {\n  width: 600px;\n}\n@media (max-width: 992px) {\n.g-dialog__content--sm {\n    width: 500px;\n}\n}\n@media (max-width: 576px) {\n.g-dialog__content--sm {\n    width: 100%;\n}\n}\n.g-dialog__content--xs {\n  width: 400px;\n}\n@media (max-width: 576px) {\n.g-dialog__content--xs {\n    width: 100%;\n}\n}\n.g-dialog__content-header {\n  padding-bottom: 18px;\n}\n@media (max-width: 1200px) {\n.g-dialog__content-header {\n    padding-bottom: 16px;\n}\n}\n@media (max-width: 992px) {\n.g-dialog__content-header {\n    padding-bottom: 14px;\n}\n}\n@media (max-width: 768px) {\n.g-dialog__content-header {\n    padding-bottom: 12px;\n}\n}\n@media (max-width: 576px) {\n.g-dialog__content-header {\n    padding-bottom: 10px;\n}\n}\n.g-dialog__content-footer {\n  padding-top: 18px;\n}\n@media (max-width: 1200px) {\n.g-dialog__content-footer {\n    padding-top: 16px;\n}\n}\n@media (max-width: 992px) {\n.g-dialog__content-footer {\n    padding-top: 14px;\n}\n}\n@media (max-width: 768px) {\n.g-dialog__content-footer {\n    padding-top: 12px;\n}\n}\n@media (max-width: 576px) {\n.g-dialog__content-footer {\n    padding-top: 10px;\n}\n}\n.g-dialog__content-title {\n  font-size: 1.3rem;\n  color: #333333;\n  font-weight: 600;\n  margin: 0;\n}\n@media (max-width: 1200px) {\n.g-dialog__content-title {\n    font-size: 1.25rem;\n}\n}\n@media (max-width: 992px) {\n.g-dialog__content-title {\n    font-size: 1.2rem;\n}\n}\n@media (max-width: 768px) {\n.g-dialog__content-title {\n    font-size: 1.15rem;\n}\n}\n@media (max-width: 576px) {\n.g-dialog__content-title {\n    font-size: 1.1rem;\n}\n}\n.g-dialog__close-btn {\n  position: absolute;\n  top: 12px;\n  right: 12px;\n  width: 18px;\n  height: 18px;\n  padding: 4px;\n  border-radius: 50%;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  background-color: transparent;\n  border: none;\n  cursor: pointer;\n}\n.g-dialog__close-btn:hover {\n  background-color: #ffffff;\n  box-shadow: 0 5px 20px 0 rgba(0, 0, 0, 0.2);\n}\n.g-dialog__close-btn-icon {\n  width: 100%;\n}\n@media (max-width: 768px) {\n.g-dialog__close-btn {\n    top: 11px;\n    right: 11px;\n}\n}\n@media (max-width: 576px) {\n.g-dialog__close-btn {\n    top: 10px;\n    right: 10px;\n}\n}\n.fade-enter-active, .fade-leave-active {\n  opacity: 0;\n  transition: opacity 0.4s;\n}\n.fade-enter, .fade-leave-to, .fade-leave-active {\n  opacity: 0;\n  transition: opacity 0.2s;\n}\n.in-out-enter-active, .in-out-leave-active {\n  transition: opacity 0.5s;\n  transform: translateY(0);\n}\n.in-out-enter, .in-out-leave-to, .in-out-leave-active {\n  opacity: 0;\n  transform: translateY(100px);\n}\n.slide-fade-enter-active {\n  transition: all 0.4s ease;\n  transform: translateX(10px);\n}\n.slide-fade-leave-active {\n  transition: all 0.2s cubic-bezier(1, 0.5, 0.8, 1);\n  transform: translateX(10px);\n}\n.slide-fade-enter, .slide-fade-leave-to, .slide-fade-leave-active {\n  transform: translateX(-10px);\n  opacity: 0;\n}\n.bounce-enter-active {\n  animation: bounce-in 0.5s;\n}\n.bounce-leave-active {\n  animation: bounce-in 0.5s reverse;\n}\n@keyframes bounce-in {\n0% {\n    transform: scale(0);\n}\n50% {\n    transform: scale(1.5);\n}\n100% {\n    transform: scale(1);\n}\n}\n.slide-right-to-left-enter-active {\n  animation: slide-right-to-left-in 0.3s ease-in-out;\n}\n@keyframes slide-right-to-left-in {\n0% {\n    transform: translateX(100%) scale(0.8);\n    opacity: 0;\n}\n100% {\n    transform: translateX(0) scale(1);\n    opacity: 1;\n}\n}\n.slide-right-to-left-leave-active {\n  animation: slide-right-to-left-out 0.3s ease-in-out;\n}\n@keyframes slide-right-to-left-out {\n0% {\n    transform: translateX(0) scale(1);\n    opacity: 1;\n}\n100% {\n    transform: translateX(-100%) scale(0.8);\n    opacity: 0;\n}\n}\n.slide-right-enter-active {\n  animation: slide-right-in 0.3s ease-in-out;\n}\n@keyframes slide-right-in {\n0% {\n    transform: translateX(100%);\n    opacity: 0;\n}\n100% {\n    transform: translateX(0);\n    opacity: 1;\n}\n}\n.slide-right-leave-active {\n  animation: slide-right-out 0.3s ease-in-out;\n}\n@keyframes slide-right-out {\n0% {\n    transform: translateX(0);\n    opacity: 1;\n}\n100% {\n    transform: translateX(-100%);\n    opacity: 0;\n}\n}\n.slide-left-enter-active {\n  animation: slide-left-in 0.5s ease-in-out;\n}\n@keyframes slide-left-in {\n0% {\n    transform: translateX(-100%);\n    opacity: 0;\n}\n100% {\n    transform: translateX(0);\n    opacity: 1;\n}\n}\n.slide-left-leave-active {\n  animation: slide-left-out 0.2s ease-in-out;\n}\n@keyframes slide-left-out {\n0% {\n    transform: translateX(0);\n    opacity: 1;\n}\n100% {\n    transform: translateX(-100%);\n    opacity: 0;\n}\n}\n.zoom-enter-active {\n  animation: zoom-in 0.5s ease-in-out;\n}\n@keyframes zoom-in {\n0% {\n    transform: scale(0.1);\n    opacity: 0;\n}\n100% {\n    transform: scale(1);\n    opacity: 1;\n}\n}\n.zoom-leave-active {\n  animation: zoom-out 0.2s ease-in-out;\n}\n@keyframes zoom-out {\n0% {\n    transform: scale(1);\n    opacity: 1;\n}\n100% {\n    transform: scale(0.1);\n    opacity: 0;\n}\n}\n.dialog-zoom-enter-active {\n  opacity: 0;\n  transition: opacity 0.2s ease-in-out;\n}\n.dialog-zoom-leave-active {\n  opacity: 0;\n  transition: opacity 0.3s ease-in-out;\n}\n.dialog-zoom-enter-active {\n  animation: zoom-in 0.3s ease-in-out;\n}\n.dialog-zoom-leave-active {\n  animation: zoom-out 0.2s ease-in-out;\n}\n.dialog-slide-top-enter-active {\n  animation: slide-top-in 0.2s ease-in-out;\n}\n@keyframes slide-top-in {\n0% {\n    transform: translateY(-100%);\n    opacity: 0;\n}\n100% {\n    transform: translateY(0);\n    opacity: 1;\n}\n}\n.dialog-slide-top-leave-active {\n  animation: slide-top-out 0.2s ease-in-out;\n}\n@keyframes slide-top-out {\n0% {\n    transform: translateY(0);\n    opacity: 1;\n}\n100% {\n    transform: translateY(-100%);\n    opacity: 0;\n}\n}\n\n/*# sourceMappingURL=Dialog.vue.map */", map: {"version":3,"sources":["Dialog.vue","/home/al_fahad/practice/npm-packages/vue-advance-dialog/src/components/Dialog.vue"],"names":[],"mappings":"AAAA;EACE,WAAW;EACX,YAAY;AACd;AACA;EACE,eAAe;EACf,MAAM;EACN,SAAS;EACT,OAAO;EACP,QAAQ;EACR,aAAa;EACb,mBAAmB;EACnB,uBAAuB;EACvB,aAAa;EACb,aAAa;EACb,gBAAgB;EAChB,gBAAgB;AAClB;AACA;AACE;IACE,aAAa;AACf;AACF;AACA;AACE;IACE,aAAa;AACf;AACF;AACA;AACE;IACE,aAAa;AACf;AACF;AACA;AACE;IACE,aAAa;AACf;AACF;AACA;EACE,mBAAmB;EACnB,uBAAuB;AACzB;AACA;EACE,mBAAmB;EACnB,2BAA2B;AAC7B;AACA;EACE,mBAAmB;EACnB,yBAAyB;AAC3B;AACA;EACE,uBAAuB;EACvB,uBAAuB;AACzB;AACA;EACE,uBAAuB;EACvB,2BAA2B;AAC7B;AACA;EACE,uBAAuB;EACvB,yBAAyB;AAC3B;AACA;EACE,qBAAqB;EACrB,uBAAuB;AACzB;AACA;EACE,qBAAqB;EACrB,2BAA2B;AAC7B;AACA;EACE,qBAAqB;EACrB,yBAAyB;AAC3B;AACA;EACE,eAAe;EACf,MAAM;EACN,SAAS;EACT,OAAO;EACP,QAAQ;EACR,eAAe;EACf,UAAU;EACV,sCAAsC;AACxC;AACA;EACE,YAAY;EACZ,sBAAsB;EACtB,UAAU;EACV,kBAAkB;EAClB,kBAAkB;EAClB,gBAAgB;EAChB,aAAa;EACb,gDAAgD;AAClD;AACA;AACE;IACE,aAAa;AACf;AACF;AACA;AACE;IACE,aAAa;AACf;AACF;AACA;AACE;IACE,aAAa;AACf;AACF;AACA;AACE;IACE,aAAa;AACf;AACF;AACA;EACE,aAAa;AACf;AACA;AACE;IACE,YAAY;AACd;AACF;AACA;AACE;IACE,YAAY;AACd;AACF;AACA;AACE;IACE,WAAW;AACb;AACF;AACA;EACE,YAAY;AACd;AACA;AACE;IACE,YAAY;AACd;AACF;AACA;AACE;IACE,WAAW;AACb;AACF;AACA;AACE;IACE,WAAW;AACb;AACF;AACA;EACE,YAAY;AACd;AACA;AACE;IACE,YAAY;AACd;AACF;AACA;AACE;IACE,WAAW;AACb;AACF;AACA;EACE,YAAY;AACd;AACA;AACE;IACE,WAAW;AACb;AACF;AACA;EACE,oBAAoB;AACtB;AACA;AACE;IACE,oBAAoB;AACtB;AACF;AACA;AACE;IACE,oBAAoB;AACtB;AACF;AACA;AACE;IACE,oBAAoB;AACtB;AACF;AACA;AACE;IACE,oBAAoB;AACtB;AACF;AACA;EACE,iBAAiB;AACnB;AACA;AACE;IACE,iBAAiB;AACnB;AACF;ACdA;ADgBE;ICfF,iBAAA;ADiBE;AACF;AACA;AACE;IACE,iBAAiB;AACnB;AACF;AACA;AACE;IACE,iBAAiB;AACnB;AACF;AACA;EACE,iBAAiB;EACjB,cAAc;EACd,gBAAgB;EAChB,SAAS;AACX;AACA;AACE;IACE,kBAAkB;AACpB;AACF;AACA;AACE;IACE,iBAAiB;AACnB;AACF;AACA;AACE;IACE,kBAAkB;AACpB;AACF;AACA;AACE;IACE,iBAAiB;AACnB;AACF;AACA;EACE,kBAAkB;EAClB,SAAS;EACT,WAAW;EACX,WAAW;EACX,YAAY;EACZ,YAAY;EACZ,kBAAkB;EAClB,aAAa;EACb,mBAAmB;EACnB,uBAAuB;EACvB,6BAA6B;EAC7B,YAAY;EACZ,eAAe;AACjB;AACA;EACE,yBAAyB;EACzB,2CAA2C;AAC7C;AACA;EACE,WAAW;AACb;AACA;AACE;IACE,SAAS;IACT,WAAW;AACb;AACF;AACA;AACE;IACE,SAAS;IACT,WAAW;AACb;AACF;AAEA;EACE,UAAU;EACV,wBAAwB;AAC1B;AAEA;EACE,UAAU;EACV,wBAAwB;AAC1B;AAEA;EACE,wBAAwB;EACxB,wBAAwB;AAC1B;AAEA;EACE,UAAU;EACV,4BAA4B;AAC9B;AAEA;EACE,yBAAyB;EACzB,2BAA2B;AAC7B;AAEA;EACE,iDAAiD;EACjD,2BAA2B;AAC7B;AAEA;EACE,4BAA4B;EAC5B,UAAU;AACZ;AAEA;EACE,yBAAyB;AAC3B;AAEA;EACE,iCAAiC;AACnC;AAEA;AACE;IACE,mBAAmB;AACrB;AACA;IACE,qBAAqB;AACvB;AACA;IACE,mBAAmB;AACrB;AACF;AACA;EACE,kDAAkD;AACpD;AAEA;AACE;IACE,sCAAsC;IACtC,UAAU;AACZ;AACA;IACE,iCAAiC;IACjC,UAAU;AACZ;AACF;AACA;EACE,mDAAmD;AACrD;AAEA;AACE;IACE,iCAAiC;IACjC,UAAU;AACZ;AACA;IACE,uCAAuC;IACvC,UAAU;AACZ;AACF;AACA;EACE,0CAA0C;AAC5C;AAEA;AACE;IACE,2BAA2B;IAC3B,UAAU;AACZ;AACA;IACE,wBAAwB;IACxB,UAAU;AACZ;AACF;AACA;EACE,2CAA2C;AAC7C;AAEA;AACE;IACE,wBAAwB;IACxB,UAAU;AACZ;AACA;IACE,4BAA4B;IAC5B,UAAU;AACZ;AACF;AACA;EACE,yCAAyC;AAC3C;AAEA;AACE;IACE,4BAA4B;IAC5B,UAAU;AACZ;AACA;IACE,wBAAwB;IACxB,UAAU;AACZ;AACF;AACA;EACE,0CAA0C;AAC5C;AAEA;AACE;IACE,wBAAwB;IACxB,UAAU;AACZ;AACA;IACE,4BAA4B;IAC5B,UAAU;AACZ;AACF;AACA;EACE,mCAAmC;AACrC;AAEA;AACE;IACE,qBAAqB;IACrB,UAAU;AACZ;AACA;IACE,mBAAmB;IACnB,UAAU;AACZ;AACF;AACA;EACE,oCAAoC;AACtC;AAEA;AACE;IACE,mBAAmB;IACnB,UAAU;AACZ;AACA;IACE,qBAAqB;IACrB,UAAU;AACZ;AACF;AACA;EACE,UAAU;EACV,oCAAoC;AACtC;ACnQA;EDsQE,UAAU;EACV,oCAAoC;AACtC;AAEA;EACE,mCAAmC;AACrC;AAEA;EACE,oCAAoC;AACtC;AAEA;EACE,wCAAwC;AAC1C;AAEA;AACE;IACE,4BAA4B;IAC5B,UAAU;AACZ;AACA;IACE,wBAAwB;IACxB,UAAU;AACZ;AACF;AACA;EACE,yCAAyC;AAC3C;AAEA;AACE;IACE,wBAAwB;IACxB,UAAU;AACZ;AACA;IACE,4BAA4B;IAC5B,UAAU;AACZ;AACF;;AAEA,qCAAqC","file":"Dialog.vue","sourcesContent":[".g-dialog {\n  width: auto;\n  height: auto;\n}\n.g-dialog__inner {\n  position: fixed;\n  top: 0;\n  bottom: 0;\n  left: 0;\n  right: 0;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  z-index: 9999;\n  padding: 30px;\n  overflow: hidden;\n  overflow-Y: auto;\n}\n@media (max-width: 1200px) {\n  .g-dialog__inner {\n    padding: 28px;\n  }\n}\n@media (max-width: 992px) {\n  .g-dialog__inner {\n    padding: 26px;\n  }\n}\n@media (max-width: 768px) {\n  .g-dialog__inner {\n    padding: 24px;\n  }\n}\n@media (max-width: 576px) {\n  .g-dialog__inner {\n    padding: 20px;\n  }\n}\n.g-dialog__inner.center-center {\n  align-items: center;\n  justify-content: center;\n}\n.g-dialog__inner.center-left {\n  align-items: center;\n  justify-content: flex-start;\n}\n.g-dialog__inner.center-right {\n  align-items: center;\n  justify-content: flex-end;\n}\n.g-dialog__inner.top-center {\n  align-items: flex-start;\n  justify-content: center;\n}\n.g-dialog__inner.top-left {\n  align-items: flex-start;\n  justify-content: flex-start;\n}\n.g-dialog__inner.top-right {\n  align-items: flex-start;\n  justify-content: flex-end;\n}\n.g-dialog__inner.bottom-center {\n  align-items: flex-end;\n  justify-content: center;\n}\n.g-dialog__inner.bottom-left {\n  align-items: flex-end;\n  justify-content: flex-start;\n}\n.g-dialog__inner.bottom-right {\n  align-items: flex-end;\n  justify-content: flex-end;\n}\n.g-dialog__overlay {\n  position: fixed;\n  top: 0;\n  bottom: 0;\n  left: 0;\n  right: 0;\n  cursor: pointer;\n  z-index: 1;\n  background-color: rgba(2, 11, 44, 0.6);\n}\n.g-dialog__content {\n  height: auto;\n  background-color: #fff;\n  z-index: 4;\n  border-radius: 5px;\n  position: relative;\n  overflow: hidden;\n  padding: 45px;\n  box-shadow: 15px 10px 30px 0 rgba(0, 0, 0, 0.05);\n}\n@media (max-width: 1200px) {\n  .g-dialog__content {\n    padding: 40px;\n  }\n}\n@media (max-width: 992px) {\n  .g-dialog__content {\n    padding: 35px;\n  }\n}\n@media (max-width: 768px) {\n  .g-dialog__content {\n    padding: 30px;\n  }\n}\n@media (max-width: 576px) {\n  .g-dialog__content {\n    padding: 25px;\n  }\n}\n.g-dialog__content--lg {\n  width: 1100px;\n}\n@media (max-width: 1200px) {\n  .g-dialog__content--lg {\n    width: 900px;\n  }\n}\n@media (max-width: 992px) {\n  .g-dialog__content--lg {\n    width: 700px;\n  }\n}\n@media (max-width: 768px) {\n  .g-dialog__content--lg {\n    width: 100%;\n  }\n}\n.g-dialog__content--md {\n  width: 900px;\n}\n@media (max-width: 992px) {\n  .g-dialog__content--md {\n    width: 700px;\n  }\n}\n@media (max-width: 768px) {\n  .g-dialog__content--md {\n    width: 100%;\n  }\n}\n@media (max-width: 576px) {\n  .g-dialog__content--md {\n    width: 100%;\n  }\n}\n.g-dialog__content--sm {\n  width: 600px;\n}\n@media (max-width: 992px) {\n  .g-dialog__content--sm {\n    width: 500px;\n  }\n}\n@media (max-width: 576px) {\n  .g-dialog__content--sm {\n    width: 100%;\n  }\n}\n.g-dialog__content--xs {\n  width: 400px;\n}\n@media (max-width: 576px) {\n  .g-dialog__content--xs {\n    width: 100%;\n  }\n}\n.g-dialog__content-header {\n  padding-bottom: 18px;\n}\n@media (max-width: 1200px) {\n  .g-dialog__content-header {\n    padding-bottom: 16px;\n  }\n}\n@media (max-width: 992px) {\n  .g-dialog__content-header {\n    padding-bottom: 14px;\n  }\n}\n@media (max-width: 768px) {\n  .g-dialog__content-header {\n    padding-bottom: 12px;\n  }\n}\n@media (max-width: 576px) {\n  .g-dialog__content-header {\n    padding-bottom: 10px;\n  }\n}\n.g-dialog__content-footer {\n  padding-top: 18px;\n}\n@media (max-width: 1200px) {\n  .g-dialog__content-footer {\n    padding-top: 16px;\n  }\n}\n@media (max-width: 992px) {\n  .g-dialog__content-footer {\n    padding-top: 14px;\n  }\n}\n@media (max-width: 768px) {\n  .g-dialog__content-footer {\n    padding-top: 12px;\n  }\n}\n@media (max-width: 576px) {\n  .g-dialog__content-footer {\n    padding-top: 10px;\n  }\n}\n.g-dialog__content-title {\n  font-size: 1.3rem;\n  color: #333333;\n  font-weight: 600;\n  margin: 0;\n}\n@media (max-width: 1200px) {\n  .g-dialog__content-title {\n    font-size: 1.25rem;\n  }\n}\n@media (max-width: 992px) {\n  .g-dialog__content-title {\n    font-size: 1.2rem;\n  }\n}\n@media (max-width: 768px) {\n  .g-dialog__content-title {\n    font-size: 1.15rem;\n  }\n}\n@media (max-width: 576px) {\n  .g-dialog__content-title {\n    font-size: 1.1rem;\n  }\n}\n.g-dialog__close-btn {\n  position: absolute;\n  top: 12px;\n  right: 12px;\n  width: 18px;\n  height: 18px;\n  padding: 4px;\n  border-radius: 50%;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  background-color: transparent;\n  border: none;\n  cursor: pointer;\n}\n.g-dialog__close-btn:hover {\n  background-color: #ffffff;\n  box-shadow: 0 5px 20px 0 rgba(0, 0, 0, 0.2);\n}\n.g-dialog__close-btn-icon {\n  width: 100%;\n}\n@media (max-width: 768px) {\n  .g-dialog__close-btn {\n    top: 11px;\n    right: 11px;\n  }\n}\n@media (max-width: 576px) {\n  .g-dialog__close-btn {\n    top: 10px;\n    right: 10px;\n  }\n}\n\n.fade-enter-active, .fade-leave-active {\n  opacity: 0;\n  transition: opacity 0.4s;\n}\n\n.fade-enter, .fade-leave-to, .fade-leave-active {\n  opacity: 0;\n  transition: opacity 0.2s;\n}\n\n.in-out-enter-active, .in-out-leave-active {\n  transition: opacity 0.5s;\n  transform: translateY(0);\n}\n\n.in-out-enter, .in-out-leave-to, .in-out-leave-active {\n  opacity: 0;\n  transform: translateY(100px);\n}\n\n.slide-fade-enter-active {\n  transition: all 0.4s ease;\n  transform: translateX(10px);\n}\n\n.slide-fade-leave-active {\n  transition: all 0.2s cubic-bezier(1, 0.5, 0.8, 1);\n  transform: translateX(10px);\n}\n\n.slide-fade-enter, .slide-fade-leave-to, .slide-fade-leave-active {\n  transform: translateX(-10px);\n  opacity: 0;\n}\n\n.bounce-enter-active {\n  animation: bounce-in 0.5s;\n}\n\n.bounce-leave-active {\n  animation: bounce-in 0.5s reverse;\n}\n\n@keyframes bounce-in {\n  0% {\n    transform: scale(0);\n  }\n  50% {\n    transform: scale(1.5);\n  }\n  100% {\n    transform: scale(1);\n  }\n}\n.slide-right-to-left-enter-active {\n  animation: slide-right-to-left-in 0.3s ease-in-out;\n}\n\n@keyframes slide-right-to-left-in {\n  0% {\n    transform: translateX(100%) scale(0.8);\n    opacity: 0;\n  }\n  100% {\n    transform: translateX(0) scale(1);\n    opacity: 1;\n  }\n}\n.slide-right-to-left-leave-active {\n  animation: slide-right-to-left-out 0.3s ease-in-out;\n}\n\n@keyframes slide-right-to-left-out {\n  0% {\n    transform: translateX(0) scale(1);\n    opacity: 1;\n  }\n  100% {\n    transform: translateX(-100%) scale(0.8);\n    opacity: 0;\n  }\n}\n.slide-right-enter-active {\n  animation: slide-right-in 0.3s ease-in-out;\n}\n\n@keyframes slide-right-in {\n  0% {\n    transform: translateX(100%);\n    opacity: 0;\n  }\n  100% {\n    transform: translateX(0);\n    opacity: 1;\n  }\n}\n.slide-right-leave-active {\n  animation: slide-right-out 0.3s ease-in-out;\n}\n\n@keyframes slide-right-out {\n  0% {\n    transform: translateX(0);\n    opacity: 1;\n  }\n  100% {\n    transform: translateX(-100%);\n    opacity: 0;\n  }\n}\n.slide-left-enter-active {\n  animation: slide-left-in 0.5s ease-in-out;\n}\n\n@keyframes slide-left-in {\n  0% {\n    transform: translateX(-100%);\n    opacity: 0;\n  }\n  100% {\n    transform: translateX(0);\n    opacity: 1;\n  }\n}\n.slide-left-leave-active {\n  animation: slide-left-out 0.2s ease-in-out;\n}\n\n@keyframes slide-left-out {\n  0% {\n    transform: translateX(0);\n    opacity: 1;\n  }\n  100% {\n    transform: translateX(-100%);\n    opacity: 0;\n  }\n}\n.zoom-enter-active {\n  animation: zoom-in 0.5s ease-in-out;\n}\n\n@keyframes zoom-in {\n  0% {\n    transform: scale(0.1);\n    opacity: 0;\n  }\n  100% {\n    transform: scale(1);\n    opacity: 1;\n  }\n}\n.zoom-leave-active {\n  animation: zoom-out 0.2s ease-in-out;\n}\n\n@keyframes zoom-out {\n  0% {\n    transform: scale(1);\n    opacity: 1;\n  }\n  100% {\n    transform: scale(0.1);\n    opacity: 0;\n  }\n}\n.dialog-zoom-enter-active {\n  opacity: 0;\n  transition: opacity 0.2s ease-in-out;\n}\n\n.dialog-zoom-leave-active {\n  opacity: 0;\n  transition: opacity 0.3s ease-in-out;\n}\n\n.dialog-zoom-enter-active {\n  animation: zoom-in 0.3s ease-in-out;\n}\n\n.dialog-zoom-leave-active {\n  animation: zoom-out 0.2s ease-in-out;\n}\n\n.dialog-slide-top-enter-active {\n  animation: slide-top-in 0.2s ease-in-out;\n}\n\n@keyframes slide-top-in {\n  0% {\n    transform: translateY(-100%);\n    opacity: 0;\n  }\n  100% {\n    transform: translateY(0);\n    opacity: 1;\n  }\n}\n.dialog-slide-top-leave-active {\n  animation: slide-top-out 0.2s ease-in-out;\n}\n\n@keyframes slide-top-out {\n  0% {\n    transform: translateY(0);\n    opacity: 1;\n  }\n  100% {\n    transform: translateY(-100%);\n    opacity: 0;\n  }\n}\n\n/*# sourceMappingURL=Dialog.vue.map */","<template>\n    <div :id=\"id\" class=\"g-dialog\" :class=\"containerClass\">\n        <button v-if=\"!hideToggle\" class=\"g-dialog__toggle\" type=\"button\"\n                :class=\"toggleClass\" @click=\"showDialog\"\n                :disabled=\"disabled\">\n            {{ toggleTitle ? toggleTitle : '' }}\n            <slot name=\"toggle\"/>\n        </button>\n\n        <transition name=\"dialog-fade\">\n            <div class=\"g-dialog__inner\" :class=\"position\" v-if=\"isActive\">\n                <div class=\"g-dialog__overlay\" @click=\"hideDialog\"></div>\n                <transition :name=\"'dialog-'+transition\">\n                    <div class=\"g-dialog__content\" :class=\"'g-dialog__content--'+size + '' + contentClass\"\n                         v-if=\"activated\">\n                        <button v-if=\"!hideCloseButton\" type=\"button\" class=\"g-dialog__close-btn\" @click=\"hideDialog\">\n                            <!--                            <img src=\"../assets/images/icons/close.png\" class=\"g-dialog__close-btn-icon\" alt=\"Close\">-->\n                        </button>\n                        <div class=\"g-dialog__content-header\" :class=\"contentHeaderClass\" v-if=\"!hideHeader\">\n                            <slot name=\"header\"/>\n                            <h5 v-if=\"title\" class=\"g-dialog__content-title\" v-text=\"title\"></h5>\n                        </div>\n                        <div v-if=\"!hideBody\" class=\"g-dialog__content-inner\" :class=\"contentInnerClass\">\n                            <slot/>\n                        </div>\n                        <slot v-else/>\n                        <div class=\"g-dialog__content-footer\" :class=\"contentFooterClass\" v-if=\"!hideFooter\">\n                            <slot name=\"footer\"/>\n                        </div>\n                    </div>\n                </transition>\n            </div>\n        </transition>\n    </div>\n</template>\n\n<script>\nimport EventHub from \"../../plugins/EventHub\";\n\nexport default {\n    name: 'vue-advance-dialog',\n\n    props: {\n        id: {\n            type: String,\n            required: true,\n            default: 'g-dialog_' + Number(Math.random() * 100).toFixed(0)\n        },\n        toggleClass: {\n            type: String,\n            required: false,\n            default: 'btn btn-primary'\n        },\n        toggleTitle: {\n            type: String,\n            required: false,\n            default: ''\n        },\n        hideHeader: {\n            type: Boolean,\n            required: false,\n            default: false\n        },\n        hideBody: {\n            type: Boolean,\n            required: false,\n            default: false\n        },\n        disabled: {\n            type: Boolean,\n            required: false,\n            default: false\n        },\n        hideFooter: {\n            type: Boolean,\n            required: false,\n            default: true\n        },\n        hideCloseButton: {\n            type: Boolean,\n            required: false,\n            default: false\n        },\n        hideToggle: {\n            type: Boolean,\n            required: false,\n            default: true\n        },\n        size: {\n            type: String,\n            required: false,\n            default: 'xs'\n            // lg, md, sm, xs\n        },\n        position: {\n            type: String,\n            required: false,\n            default: 'top-center'\n            // center-center, center-left, center-right, top-center, top-left, top-right, bottom-center, bottom-left, bottom-right\n        },\n        title: {\n            type: String,\n            required: false,\n            default: ''\n        },\n        containerClass: {\n            type: String,\n            required: false,\n            default: ''\n        },\n        contentClass: {\n            type: String,\n            required: false,\n            default: ''\n        },\n        contentHeaderClass: {\n            type: String,\n            required: false,\n            default: ''\n        },\n        contentInnerClass: {\n            type: String,\n            required: false,\n            default: ''\n        },\n        contentFooterClass: {\n            type: String,\n            required: false,\n            default: ''\n        },\n        transition: {\n            type: String,\n            required: false,\n            default: 'slide-top'\n        },\n    },\n\n    data() {\n        return {\n            isActive: false,\n            activated: false,\n        };\n    },\n    watch: {\n        isActive(value) {\n            if (value === true) {\n                this.$emit('activated')\n            } else {\n                this.$emit('deactivated')\n            }\n        }\n    },\n    mounted() {\n        EventHub.$on('hide-all-dialog', () => {\n            this.hideDialog()\n        })\n        EventHub.$on('hide-dialog', (id) => {\n            if (this.id !== id) return\n            this.hideDialog()\n        })\n\n        EventHub.$on('show-dialog', (id) => {\n            if (this.id !== id) return\n            this.showDialog()\n        })\n    },\n    methods: {\n        showDialog() {\n            this.isActive = true\n            this.$emit('after-show')\n            setTimeout(() => {\n                this.activated = true\n            }, 100)\n        },\n\n        hideDialog() {\n            this.activated = false\n            this.$emit('after-hide')\n            return setTimeout(() => {\n                this.isActive = false\n            }, 200)\n        }\n    }\n};\n</script>\n\n<style lang=\"scss\">\n@import \"../assets/scss/dialog\";\n@import \"../assets/scss/transitions\";\n</style>"]}, media: undefined });

      };
      /* scoped */
      var __vue_scope_id__ = undefined;
      /* module identifier */
      var __vue_module_identifier__ = undefined;
      /* functional template */
      var __vue_is_functional_template__ = false;
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      var __vue_component__ = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
        __vue_inject_styles__,
        __vue_script__,
        __vue_scope_id__,
        __vue_is_functional_template__,
        __vue_module_identifier__,
        false,
        createInjector,
        undefined,
        undefined
      );

    function install(Vue) {
        if (install.installed) { return; }
        install.installed = true;
        Vue.component('vue-advance-dialog', __vue_component__);
    }

    var plugin = {
        install: install,
    };

    var GlobalVue = null;
    if (typeof window !== 'undefined') {
        GlobalVue = window.Vue;
    } else if (typeof global !== 'undefined') {
        GlobalVue = global.Vue;
    }
    if (GlobalVue) {
        GlobalVue.use(plugin);
    }

    exports["default"] = __vue_component__;
    exports.install = install;

    Object.defineProperty(exports, '__esModule', { value: true });

    return exports;

})({}, emitter);
